==> python-awips-0.9.4.tar.gz: python-awips-0.9.4/dynamicserialize/dstypes/com/raytheon/uf/common/datastorage/records/__init__.py <==
##
# This software was developed and / or modified by Raytheon Company,
# pursuant to Contract DG133W-05-CQ-1067 with the US Government.
#
# U.S. EXPORT CONTROLLED TECHNICAL DATA
# This software product contains export-restricted data whose
# export/transfer/disclosure is restricted by U.S. law. Dissemination
# to non-U.S. persons whether in the United States or abroad requires
# an export license or other authorization.
#
# Contractor Name:        Raytheon Company
# Contractor Address:     6825 Pine Street, Suite 340
#                         Mail Stop B8
#                         Omaha, NE 68106
#                         402.291.0100
#
# See the AWIPS II Master Rights File ("Master Rights File.pdf") for
# further licensing information.
##

#
# Package definition for com.raytheon.uf.common.datastorage.records
#
#
#     SOFTWARE HISTORY
#
#    Date            Ticket#       Engineer       Description
#    ------------    ----------    -----------    --------------------------
#    08/31/10                      njensen        Initial Creation.
#    Apr 24, 2015    4425          nabowle        Add DoubleDataRecord
#
#
#


__all__ = [
            'ByteDataRecord',
            'DoubleDataRecord',
            'FloatDataRecord',
            'IntegerDataRecord',
            'LongDataRecord',
            'ShortDataRecord',
            'StringDataRecord'
          ]

from ByteDataRecord import ByteDataRecord
from DoubleDataRecord import DoubleDataRecord
from FloatDataRecord import FloatDataRecord
from IntegerDataRecord import IntegerDataRecord
from LongDataRecord import LongDataRecord
from ShortDataRecord import ShortDataRecord
from StringDataRecord import StringDataRecord

==> python-awips-20.1.tar.gz: python-awips-20.1/dynamicserialize/dstypes/com/raytheon/uf/common/datastorage/records/__init__.py <==
##
# This software was developed and / or modified by Raytheon Company,
# pursuant to Contract DG133W-05-CQ-1067 with the US Government.
#
# U.S. EXPORT CONTROLLED TECHNICAL DATA
# This software product contains export-restricted data whose
# export/transfer/disclosure is restricted by U.S. law. Dissemination
# to non-U.S. persons whether in the United States or abroad requires
# an export license or other authorization.
#
# Contractor Name:        Raytheon Company
# Contractor Address:     6825 Pine Street, Suite 340
#                         Mail Stop B8
#                         Omaha, NE 68106
#                         402.291.0100
#
# See the AWIPS II Master Rights File ("Master Rights File.pdf") for
# further licensing information.
##

#
# Package definition for com.raytheon.uf.common.datastorage.records
#
#
#     SOFTWARE HISTORY
#
#    Date            Ticket#       Engineer       Description
#    ------------    ----------    -----------    --------------------------
#    08/31/10                      njensen        Initial Creation.
#    Apr 24, 2015    4425          nabowle        Add DoubleDataRecord
#    Sep 28, 2021    8608          mapeters       Add metadata classes
#
#
#

__all__ = [
            'ByteDataRecord',
            'DataUriMetadataIdentifier',
            'DoubleDataRecord',
            'FloatDataRecord',
            'IntegerDataRecord',
            'LongDataRecord',
            'NoMetadataIdentifier',
            'RecordAndMetadata',
            'ShortDataRecord',
            'StringDataRecord'
          ]

from .ByteDataRecord import ByteDataRecord
from .DataUriMetadataIdentifier import DataUriMetadataIdentifier
from .DoubleDataRecord import DoubleDataRecord
from .FloatDataRecord import FloatDataRecord
from .IntegerDataRecord import IntegerDataRecord
from .LongDataRecord import LongDataRecord
from .NoMetadataIdentifier import NoMetadataIdentifier
from .RecordAndMetadata import RecordAndMetadata
from .ShortDataRecord import ShortDataRecord
from .StringDataRecord import StringDataRecord
